/*! Copyright (c) 2002-2008 SAS Institute, Inc.  All rights reserved. */

/* ------------------------------------------------------------------------ *
 * Purpose: Contains the javascript classes and methods for the             *
 *          RemoteFileSelector class                                        *
 *                                                                          *
 * Author:                                                                  *
 * Version:  1.0                                                            *
 *                                                                          *
 * ------------------------------------------------------------------------ */
//JavaScript for com.sas.servlet.tbeans.remotefileselector.html.RemoteFileSelector
//sasaga 12/18/02
sas.provides("sas_RemoteFileSelector");
///////////////////////////////////////////////////////
//
// Process the selection made in the Location
// drop-down component.
//
// openFolderBaseURL - base url retrieved from 
//               openFolderAction, it includes the
//               CMDID identifying the
//               OpenFolderCommand for execution
// searchResultsBaseURL - base url retrieved
//               from DisplaySearchResultsAction,
//               it inculdes the CMDID
//               identifying the 
//               DisplaySearchResultsCommand for
//               execution
//
///////////////////////////////////////////////////////
function sas_RemoteFileSelector_processLocationSelection(openFolderBaseURL, searchResultsBaseURL, value)
{
   //if the "Search Results" node selected
   //then return to the previously generated search results
   if(value == "SEARCH_RESULTS")
   {
      location = searchResultsBaseURL;
   }
   else
   {
      location = openFolderBaseURL + value;
   }  

} //end of processLocationSelection
function sas_RemoteFileSelector_processLocationSelection2(openFolderBaseURL, searchResultsBaseURL, comboBoxViewId)
{
   //if the "Search Results" node selected
   //then return to the previously generated search results
   var value = sas_getJavaScriptObject( comboBoxViewId ).getValue();
   if(value == "SEARCH_RESULTS")
   {
      location = searchResultsBaseURL;
   }
   else
   {
      location = openFolderBaseURL + value;
   } 

} //end of processLocationSelection

function sas_RemoteFileSelector_processLocationSelectionUsingAJAX(openFolderBaseURL, searchResultsBaseURL, comboBoxViewId)
{
   //if the "Search Results" node selected
   //then return to the previously generated search results
   var value = sas_getJavaScriptObject( comboBoxViewId ).getValue();
   if(value == "SEARCH_RESULTS")
   {
      return sas.ajax.doAction(searchResultsBaseURL);
   }
   else
   {
      completeURLForOpenFolderLocation = openFolderBaseURL + value;
      return sas.ajax.doAction(completeURLForOpenFolderLocation);
   }  

} //end of processLocationSelectionUsingAJAX

///////////////////////////////////////////////////////
//
// Process search from RemoteFileSelector component
//
// formName - name of the form that contains the 
//            startDate & endDate hidden fields
// parameterPrefix - Action provider prefix
// unitValueParmName - name of component (text
//            entry) that contains the # to use
//            for calculating the relative Date 
// unitTypeParmName - the name of the component that 
//            contains the time unit used to 
//            determine how
//            far back the search should query
//            valid values: Hours, Days, Weeks, Months
//	    
//
///////////////////////////////////////////////////////
function sas_RemoteFileSelector_processSearch( formName, parameterPrefix, dateTimeLimitParmName, unitValueParmName, unitTypeParmName )
{

    sas_RemoteFileSelector_processSearchUsingAJAX( formName, parameterPrefix, dateTimeLimitParmName, unitValueParmName, unitTypeParmName, null);	

} //end of _processSearch

function sas_RemoteFileSelector_processSearchUsingAJAX( formName, parameterPrefix, dateTimeLimitParmName, unitValueParmName, unitTypeParmName, partialRefreshURL)
{

	//Determine the dateTimeLimit type
	dateTimeLimitValue = document.forms[formName].elements[dateTimeLimitParmName].value;

	if( dateTimeLimitValue == "none" )
	{
		//set hidden field values
		document.forms[formName].elements[parameterPrefix + "startDateTime"].value = "";
		document.forms[formName].elements[parameterPrefix + "endDateTime"].value = "";
	}

	else
	{

		//Determine the values to process
		unitValue = document.forms[formName].elements[unitValueParmName].value;
		unitType = document.forms[formName].elements[unitTypeParmName].value;
		
		//Determine the endDate
		endDateTime = (new Date()).getTime();

		//Convert unitValue based on the unitType (mins, hours, weeks)
		// 1000 Milliseconds in a second
		// 1000 * 60 Milliseconds in a minute
		// 1000 * 60 * 60 Milliseconds in an hour
		// 1000 * 60 * 60 * 24 Milliseconds in a day
		// 1000 * 60 * 60 * 24 * 7 Milliseconds in a week
		// 1000 * 60 * 60 * 24 * 30 Milliseconds in a month
		switch (unitType)
		{
	//		case "Minutes" :
	//		   diffInMilliSecs = 60000 * unitValue;
	//		   break;
			case "Hours" :
			   diffInMilliSecs = 3600000 * unitValue;
			   break;
 			case "Days" :
			   diffInMilliSecs = 86400000 * unitValue;
			   break;
			case "Weeks" :
			   diffInMilliSecs = 604800000 * unitValue;
			   break;
			case "Months":
			   diffInMilliSecs = 2592000000 * unitValue;  //this counts 30 days in a month & does not take into 
			   break;				      //account that different months have diff # of days	
			default :
			   diffInMilliSecs = 0;
			   break;
		}
	
		//Determine the startDate
		startDateTime = endDateTime - diffInMilliSecs;

		//set hidden field values
		document.forms[formName].elements[parameterPrefix + "startDateTime"].value = startDateTime;
		document.forms[formName].elements[parameterPrefix + "endDateTime"].value = endDateTime;

	} //end of else
	
	//alert("****executing fix****search sub folders value:  "+document.forms[formName].elements[parameterPrefix+"recursive"].value);
		
	//make sure checkbox value can be sent by enabling it just before submission
	//when the search is written out again the checkbox should be enabled
	//fix for defect s0647279
	var searchsubComponent = document.forms[formName].elements[parameterPrefix + "recursive"];
	if(searchsubComponent != null){
		searchsubComponent.disabled = false;
	}

    if (partialRefreshURL == null) {
       //submit the form
       document.forms[formName].submit();       
    }//if partialRefreshURL is null
    else {
       var form = document.forms[formName];
       var formParms = sas_RemoteFileSelector_buildQueryStringFromFormElements(form);
       var completeAJAXUrl = partialRefreshURL;
	   if ( (formParms != null) && (formParms != '') )
	      completeAJAXUrl = partialRefreshURL + formParms;

	   return sas.ajax.doAction(completeAJAXUrl);       
    } //else

    
} //end of _processSearchUsingAJAX

//copied from sas_tableview.js, should be generic method???
function sas_RemoteFileSelector_buildQueryStringFromFormElements(form)
{
	if( form == null )
		return null;
		
	var formParms = null;
	for (var i=0; i<form.elements.length; i++) {
		var element = form.elements[i];
		if ( (element.name != null) && (element.name != '') && (element.value != null) ) {
 			var pair = "&"+form.elements[i].name+"="+form.elements[i].value;
 			if ( formParms == null )
 				formParms = pair;
 			else
 				formParms = formParms+pair;
 		}
 	}
 	return formParms;
}

///////////////////////////////////////////////////////
//
// Display or hide the description based on the 
// value from the show descriptions checkbox.
// The cells with the descriptions is passed in
// and the parent nodes are retrieved for the
// cells and used to set the style on the 
// parent table row tag.
//
// showDescriptions - checked value of show 
//            Descriptions checkbox, 
//            if "on" the descriptions
//            should be displayed by setting
//            the table row elements style to "block"
//            else the descriptions should be 
//            hidden by setting the table row
//            elements style to "hide" 
//
// descriptionCells - table cells that contain 
//            descriptions
//
///////////////////////////////////////////////////////
function sas_RemoteFileSelector_updateDescriptionDisplayStatus(showDescriptions,descriptionCells)
{
 	//Verify existence of array of descriptions before processing descriptions
     	if(descriptionCells != null)
     	{
        	//set the visibility style based on whether the show descriptions checkbox is checked
	        //var visibility = showDescriptions ? "table-row":"none";  //"table-row" does not work for IE, "block" does not work for FF
	        //found new approach
	        var visibility = showDescriptions ? "":"none";

	        //set the style for all of the description rows so that they are hidden or visible 
        	for (var i=0; i<descriptionCells.length; i++)
	        {
        	   // descriptionCells[i].parentNode.style.display = visibility;
        	   descriptionCells[i].style.display = visibility;
	        }
	} //if (descriptionsCells array exists

}

//////////////////////////////////////////////////////////
//
// Display or hide the search area depending on the current
// state of the component.
//
// searchDisplayArea - id of area containing the 
// search fields and search/cancel buttons, 
// when searchMode is on, this area is hidden by default
//
// showSearchArea - determines whether the search area
// is visible or not, the component's style is set
// to "block" if showSearchArea is true and 
// the component's style is set to "none" otherwise
//
// expandButtonId - id/name of button with maximize image.
// Expand button object is obtained using this id.
// when the expandButton is selected the search area is
// expanded or opened
//
// collapseButton - id/name of button with minimize image.
// Collapse button object is obtained using this id.
// When this button is selected the search area is
// closed
//
// This method is not used by the remotefileselector2
// package component.  The remotefileselector2
// package component uses the ExpandCollapse component.
//
//////////////////////////////////////////////////////////
function sas_RemoteFileSelector_expandCollapseSearch(searchDisplayArea, showSearchArea, expandButtonId, collapseButtonId)
{

	//Retreive the expandButton object and the collapsebutton object
	//Netscape much happier if I use getElementById technique
	expandButton = document.getElementById(expandButtonId);
	collapseButton = document.getElementById(collapseButtonId);

	//If showSearchArea is true then expand search by setting style to "block"
	//disable expand button and enable collapse button
	if( showSearchArea )
	{
		//set style so search area is visible
		document.getElementById(searchDisplayArea).style.display = "block";

		//verify existence of setEnabled function before setting values
		//not common attribute for all buttons (html button)
		if(expandButton.setEnabled != null && typeof(expandButton.setEnabled) == "function")
		{
			expandButton.setEnabled(false);
		}

		
		if(collapseButton.setEnabled != null && typeof(collapseButton.setEnabled) == "function")
		{
			collapseButton.setEnabled(true);		
		}
	}

	//If showSearchArea is false then hide or collapse the search area by setting style to "block"
	//enable expand button and disable collapse button
	else
	{
		//set style so search area is hidden
		document.getElementById(searchDisplayArea).style.display = "none";

		//verify existence of setEnabled function before setting values
		//not common attribute for all buttons (html button)
		if(expandButton.setEnabled != null && typeof(expandButton.setEnabled) == "function")
		{
			expandButton.setEnabled(true);
		}

		if(collapseButton.setEnabled != null && typeof(collapseButton.setEnabled) == "function")
		{
			collapseButton.setEnabled(false);
		}
	}
}

